@@ -1,11 +1,13 @@
 #' Extract a single character from a string, using its index.
 #'
-#' See [strex::str_elem()].
+#' Copy of [strex::str_elem()].
 #'
-#' @inheritParams strex::str_elem
+#' @inheritParams match_arg
 #'
 #' @export
-str_elem <- strex::str_elem
+str_elem <- function(...) {
+  strex::str_elem(...)
+}
 
 #' @rdname str_elem
 #' @export
@@ -13,12 +15,14 @@ elem <- str_elem
 
 #' Extract several single elements from a string.
 #'
-#' See [strex::str_elems()].
+#' Copy of [strex::str_elems()].
 #'
-#' @inheritParams strex::str_elems
+#' @inheritParams match_arg
 #'
 #' @export
-str_elems <- strex::str_elems
+str_elems <- function(...) {
+  strex::str_elems(...)
+}
 
 #' @rdname str_elems
 #' @export
@@ -26,12 +30,14 @@ elems <- str_elems
 
 #' Extract bits of a string and paste them together.
 #'
-#' See [strex::str_paste_elems()].
+#' Copy of [strex::str_paste_elems()].
 #'
-#' @inheritParams strex::str_paste_elems
+#' @inheritParams match_arg
 #'
 #' @export
-str_paste_elems <- strex::str_paste_elems
+str_paste_elems <- function(...) {
+  strex::str_paste_elems(...)
+}
 
 #' @rdname str_paste_elems
 #' @export
