@@ -1,11 +1,13 @@
 #' Extract non-numbers from a string.
 #'
-#' See [strex::str_extract_non_numerics()]
+#' Copies of [strex::str_extract_non_numerics()] and friends.
 #'
-#' @inheritParams strex::str_extract_non_numerics
+#' @inheritParams match_arg
 #'
 #' @export
-extract_non_numerics <- strex::str_extract_non_numerics
+extract_non_numerics <- function(...){
+  strex::str_extract_non_numerics(...)
+}
 
 #' @rdname extract_non_numerics
 #' @export
@@ -14,7 +16,9 @@ str_extract_non_numerics <- extract_non_numerics
 #' @rdname extract_non_numerics
 #' @inheritParams strex::str_nth_non_numeric
 #' @export
-nth_non_numeric <- strex::str_nth_non_numeric
+nth_non_numeric <- function(...){
+  strex::str_nth_non_numeric(...)
+}
 
 #' @rdname extract_non_numerics
 #' @export
@@ -22,7 +26,9 @@ str_nth_non_numeric <- nth_non_numeric
 
 #' @rdname extract_non_numerics
 #' @export
-first_non_numeric <- strex::str_first_non_numeric
+first_non_numeric <- function(...){
+  strex::str_first_non_numeric(...)
+}
 
 #' @rdname extract_non_numerics
 #' @export
@@ -30,7 +36,9 @@ str_first_non_numeric <- first_non_numeric
 
 #' @rdname extract_non_numerics
 #' @export
-last_non_numeric <- strex::str_last_non_numeric
+last_non_numeric <- function(...){
+  strex::str_last_non_numeric(...)
+}
 
 #' @rdname extract_non_numerics
 #' @export
