@@ -1,11 +1,13 @@
 #' Locate the braces in a string.
 #'
-#' See [strex::str_locate_braces()].
+#' Copy of [strex::str_locate_braces()].
 #'
-#' @inheritParams strex::str_locate_braces
+#' @inheritParams match_arg
 #'
 #' @export
-locate_braces <- strex::str_locate_braces
+locate_braces <- function(...) {
+  strex::str_locate_braces(...)
+}
 
 #' @rdname locate_braces
 #' @export
@@ -13,12 +15,14 @@ str_locate_braces <- locate_braces
 
 #' Get the indices of the \eqn{n}th instance of a pattern.
 #'
-#' See [strex::str_locate_nth()].
+#' Copy of [strex::str_locate_nth()].
 #'
-#' @inheritParams strex::str_locate_nth
+#' @inheritParams match_arg
 #'
 #' @export
-str_locate_nth <- strex::str_locate_nth
+str_locate_nth <- function(...) {
+  strex::str_locate_nth(...)
+}
 
 #' @rdname str_locate_nth
 #' @export
@@ -26,7 +30,9 @@ locate_nth <- str_locate_nth
 
 #' @rdname str_locate_nth
 #' @export
-str_locate_first <- strex::str_locate_first
+str_locate_first <- function(...) {
+  strex::str_locate_first(...)
+}
 
 #' @rdname str_locate_nth
 #' @export
@@ -34,7 +40,9 @@ locate_first <- str_locate_first
 
 #' @rdname str_locate_nth
 #' @export
-str_locate_last <- strex::str_locate_last
+str_locate_last <- function(...) {
+  strex::str_locate_last(...)
+}
 
 #' @rdname str_locate_nth
 #' @export
