@@ -1,11 +1,13 @@
 #' Split a string by its numeric characters.
 #'
-#' See [strex::str_split_by_numbers()].
+#' Copy of [strex::str_split_by_numbers()].
 #'
-#' @inheritParams strex::str_split_by_numbers
+#' @inheritParams match_arg
 #'
 #' @export
-str_split_by_nums <- strex::str_split_by_numbers
+str_split_by_nums <- function(...) {
+  strex::str_split_by_numbers(...)
+}
 
 #' @rdname str_split_by_nums
 #' @export
